<?php

declare(strict_types=1);

namespace Drupal\simple_interactive_maps\Controller;

use Drupal\simple_interactive_maps\InteractiveMapInterface;
use Symfony\Component\HttpFoundation\BinaryFileResponse;
use Symfony\Component\HttpKernel\Exception\HttpException;

/**
 * Download the state data as a CSV file.
 */
final class RegionExportController extends DataExportControllerBase {

  /**
   * Builds the response.
   */
  public function __invoke(InteractiveMapInterface $interactive_map = NULL): BinaryFileResponse {

    if (!($interactive_map instanceof InteractiveMapInterface)) {
      throw new HttpException(404, 'Interactive map not found');
    }

    $regions = $interactive_map->getRegions();

    $headers = [
      'id',
      'label',
      'hidden',
      'group',
      'fill_color',
      'hover_color',
      'stroke_color',
      'tooltip_value',
      'tooltip_format',
      'action',
      'url',
      'content_value',
      'content_format',
    ];

    $data = [];

    foreach ($regions as $region) {
      $data[] = [
        $region['id'],
        $region['label'],
        (int) $region['hidden'],
        $region['group'],
        $region['fill_color'],
        $region['hover_color'],
        $region['stroke_color'],
        $region['tooltip']['value'],
        $region['tooltip']['format'],
        $region['action'],
        $region['url'],
        $region['content']['value'],
        $region['content']['format'],
      ];
      // Export state.
    }

    $fileName = $interactive_map->id() . '_regions.csv';

    return $this->exportCsvFile($data, $headers, $fileName);

  }

}
